﻿using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;

namespace DmisMenu
{
    public partial class AddProgramForm : Form
    {
        private int formHeight = 0;
        private int formWidth = 0;
        private String DefaultPcdmisPath;
        private String _RemoteDataType;

        public AddProgramForm(String HomePath, String[] probeList)
        {
            InitializeComponent();
            DefaultPcdmisPath = HomePath;
            cbProbeList.Items.Clear();
            if (probeList != null) cbProbeList.Items.AddRange(probeList);

            this.AcceptButton = btnOk;
            this.CancelButton = btnCancel;

            ProgramName = "";
            ApplicationFolder = "";
            PcdmisProgram = "";
            DefaultProbe = "";
            HasRemoteDataCopy = false;
            RemoteDataFolder = "";
            LocalDataFolder = "";
            _RemoteDataType = "";
        }

        private void RemoteDataToggle_CheckedChanged(object sender, EventArgs e)
        {
            CheckBox rb = (CheckBox)sender;

            if (rb.Checked)
            {
                formHeight = this.Size.Height;
                formWidth = this.Size.Width;
                int grpPanelHeight = this.grpRemote.Height;

                this.Size = new Size(formWidth, formHeight + grpPanelHeight + 17);

            }

            if (!rb.Checked)
            {
                this.Size = new Size(formWidth, formHeight);
            }
        }

        private void btnOk_Click(object sender, EventArgs e)
        {
            if (txbProgramName.Text == "") { txbProgramName.BackColor = Color.Red; return; }
            txbProgramName.BackColor = Color.White;

            if (txbApplicationFolder.Text == "") { txbApplicationFolder.BackColor = Color.Red; return; }
            txbApplicationFolder.BackColor = Color.White;

            if (txbPcdmisProgram.Text == "") { txbPcdmisProgram.BackColor = Color.Red; return; }
            txbPcdmisProgram.BackColor = Color.White;

            if (cbProbeList.Text == "") { cbProbeList.BackColor = Color.Red; return; }
            cbProbeList.BackColor = Color.White;

            HasRemoteDataCopy = false;
            if (RemoteDataToggle.Checked)
            {
                HasRemoteDataCopy = true;
                if (txbRemoteDataFolder.Text == "") { txbRemoteDataFolder.BackColor = Color.Red; return; }
                txbRemoteDataFolder.BackColor = Color.White;

                if (txbLocalDataFolder.Text == "") { txbLocalDataFolder.BackColor = Color.Red; return; }
                txbLocalDataFolder.BackColor = Color.White;

                if (rbFile.Checked) RemoteDataType = "File";
                if (rbFolder.Checked) RemoteDataType = "Folder";          
            }
            this.DialogResult = System.Windows.Forms.DialogResult.OK;
        }

        private void btnFolder_Click(object sender, EventArgs e)
        {
            FolderDialog.RootFolder = Environment.SpecialFolder.MyComputer;
            DialogResult result = FolderDialog.ShowDialog();
            if (result != DialogResult.OK) return; // Folder was not selected.

            String SelectedFolderPath = FolderDialog.SelectedPath;
            String senderName = ((Button)sender).Name;

            switch (senderName)
            {
                case "btnAppFolder":
                    DirectoryInfo dirInfo = new DirectoryInfo(SelectedFolderPath);
                    txbApplicationFolder.Text = dirInfo.Name;
                    break;
                case "btnRemoteData":
                    txbRemoteDataFolder.Text = SelectedFolderPath;
                    break;
                case "btnLocalData":
                    txbLocalDataFolder.Text = SelectedFolderPath;
                    break;
                default:
                    break;
            }
        }

        private void btnFile_Click(object sender, EventArgs e)
        {
            FileDialog.Title = "Select file";
            FileDialog.RestoreDirectory = true;
            FileDialog.InitialDirectory = DefaultPcdmisPath + txbApplicationFolder.Text;

            DialogResult result = FileDialog.ShowDialog();
            if (result != DialogResult.OK) return; // file was not selected.

            String SelectedFile = FileDialog.FileName;
            String senderName = ((Button)sender).Name;

            switch (senderName)
            {
                case "btnPcdmisProgram":
                    txbPcdmisProgram.Text = stripExtension(FileDialog.SafeFileName);
                    break;
                default:
                    break;
            }
        }

        protected string stripExtension(String fileName)
        {
            return Path.GetFileNameWithoutExtension(fileName);
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
        }

        public String ProgramName { get { return txbProgramName.Text; } set { txbProgramName.Text = value; } }
        public String ApplicationFolder { get { return txbApplicationFolder.Text; } set { txbApplicationFolder.Text = value; } }
        public String PcdmisProgram { get { return txbPcdmisProgram.Text; } set { txbPcdmisProgram.Text = value; } }
        public String DefaultProbe { get { return cbProbeList.Text; } set { cbProbeList.SelectedItem = value; } }
        public Boolean HasRemoteDataCopy { get; set; }
        public String RemoteDataFolder { get { return txbRemoteDataFolder.Text; } set { txbRemoteDataFolder.Text = value; } }
        public String LocalDataFolder { get { return txbLocalDataFolder.Text; } set { txbLocalDataFolder.Text = value; } }
        public String RemoteDataType
        {
            get { return _RemoteDataType; }
            set
            {
                _RemoteDataType = value;
                if (_RemoteDataType == "File") rbFile.Checked = true;
                if (_RemoteDataType == "Folder") rbFolder.Checked = true;

                RemoteDataToggle.Checked = true;
            }
        }

        private void DataType_Clicked(object sender, EventArgs e)
        {
            if (rbFile.Checked) _RemoteDataType = "File";
            if (rbFolder.Checked) _RemoteDataType = "Folder";
        }
    }

}
