﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Windows.Forms;
using DmisLib.Dmis;

namespace DmisMenu
{
    public partial class DataCopyForm : Form
    {
        private String DataMode;
        private DmisFolder RemoteFolder;
        private DmisFolder LocalFolder;

        public DataCopyForm(String dataMode, String remoteDir, String localDir)
        {
            InitializeComponent();

            lblRemoteDir.Text = remoteDir;
            lblLocalDir.Text = localDir;
            DataMode = dataMode;
            RemoteFolder = new DmisFolder(remoteDir);
            LocalFolder = new DmisFolder(localDir);
            loadRemoteDataObjects();
            loadLocalDataObjects();

            this.CancelButton = btnExit;
        }

        private void loadLocalDataObjects()
        {
            LocalDataObjects.Items.Clear();
            if (DataMode == "File")
            {
                LocalDataObjects.Items.AddRange(getFileList(LocalFolder.FolderPath));
            }

            if (DataMode == "Folder")
            {
                LocalDataObjects.Items.AddRange(getFolderList(LocalFolder.FolderPath));
            }

            LocalDataObjects.ClearSelected();
        }

        private void loadRemoteDataObjects()
        {
            RemoteDataObjects.Items.Clear();
            if (DataMode == "File")
            {
                RemoteDataObjects.Items.AddRange(getFileList(RemoteFolder.FolderPath));
                
            }

            if (DataMode == "Folder")
            {
                RemoteDataObjects.Items.AddRange(getFolderList(RemoteFolder.FolderPath));
            }

            RemoteDataObjects.ClearSelected();
        }

        private string[] getFileList(string folder)
        {
            List<string> fileList = new List<string>();
            DirectoryInfo fi = new DirectoryInfo(folder);
            IEnumerable<FileInfo> files = fi.GetFiles();
            foreach (FileInfo info in files)
            {
                fileList.Add(info.Name);
            }

            return fileList.ToArray();
        }

        private String[] getFolderList(String folder)
        {
            List<string> dirList = new List<string>();
            DirectoryInfo fi = new DirectoryInfo(folder);
            IEnumerable<DirectoryInfo> folders = fi.GetDirectories();
            foreach (DirectoryInfo info in folders)
            {
                dirList.Add(info.Name);
            }

            return dirList.ToArray();
        }

        private void btnTransfer_Click(object sender, EventArgs e)
        {
            string RemoteObject = RemoteDataObjects.Text;
            if (RemoteObject == "") return;

            String RemoteObjectPath = RemoteFolder.FolderPath + @"\" + RemoteObject;
            String LocalObjectPath = LocalFolder.FolderPath + @"\" + RemoteObject;

            if (DataMode == "File")
            {
                File.Copy(RemoteObjectPath, LocalObjectPath);
                loadLocalDataObjects();
            }

            if (DataMode == "Folder")
            {
                DmisFolder folder = new DmisFolder(LocalObjectPath);
                folder.importFiles(RemoteObjectPath, "*.dmi");
                loadLocalDataObjects();
            }


        }

        private void btnExit_Click(object sender, EventArgs e)
        {
            this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
        }

    }
}
