﻿using System;
using System.Data;
using System.IO;
using System.Diagnostics;
using System.Windows.Forms;

namespace DmisMenu
{
    using Settings = Properties.Settings;

    public partial class Mainform : Form
    {
        private String HomeDir;
        private String xmlFile;

        public Mainform()
        {
            InitializeComponent();
            HomeDir = Application.StartupPath;
            xmlFile = HomeDir + @"\DmisMenuData.xml";

            // Display the Main Form Title
            this.Text = "PC-Dmis Action Mananger  Version " + Properties.Settings.Default.Version;

            // Start Pcdmis
            InitializePcdmis();

            // DataSet
            ReadData();
            UpDateProgramList();
        }

        private void SaveData()
        {
            dmisMenuItems.WriteXml(xmlFile);
        }

        private void UpDateProgramList()
        {
            DataView.RefreshEdit();
        }

        private void ReadData()
        {
            if (!File.Exists(xmlFile)) return;

            dmisMenuItems.ReadXml(xmlFile);
        }

        private DmisMenuItems.MenuItemsRow SelectedRow()
        {
            DataGridViewSelectedRowCollection col = DataView.SelectedRows;
            if (col.Count < 1) return null; // return null, no row is selected

            DataRowView drow = (DataRowView)col[0].DataBoundItem;
            DmisMenuItems.MenuItemsRow row = (DmisMenuItems.MenuItemsRow)drow.Row;
            return row;
        }

        // View pdf file via Acrobat Program.
        private void ShowPdfReport(String ReportName)
        {
            String PdfApp = Settings.Default.AcrobatApp;
            if (File.Exists(PdfApp))
            {
                using (Process p = new Process())
                {
                    p.StartInfo.FileName = PdfApp;
                    p.StartInfo.Arguments = ReportName;
                    p.StartInfo.UseShellExecute = false;
                    p.Start();
                }
            }
        }

        /* ======================= Application methods & functions above this line ==================================*/
        /* ============================ DOTNET Event Handlers below this line =======================================*/

        private void MenuItem_AddProgram_Click(object sender, EventArgs e)
        {
            String[] probeList = null;

            try
            {
                probeList = CMMsession.ProbeList();
            }
            catch (Exception ex)
            {
                MessageBox.Show("Missing Probe Folder " + ex.Message, "Missing Probe Info", MessageBoxButtons.OK, MessageBoxIcon.Information);
            }

            using (AddProgramForm frm = new AddProgramForm(DefaultPcdmisPath, probeList))
            {
                frm.btnOk.Text = "Add Program";
                DialogResult result = frm.ShowDialog();
                if (result == DialogResult.OK)
                {
                    
                    DmisMenuItems.MenuItemsRow row = dmisMenuItems.MenuItems.NewMenuItemsRow();
                    row.ItemName = frm.ProgramName;
                    row.AppName = frm.ApplicationFolder;
                    row.ProgamName = frm.PcdmisProgram;
                    row.DefaultTip = frm.DefaultProbe;
                    row.UsesDataCopy = frm.HasRemoteDataCopy;
                    row.RemoteDataPath = frm.RemoteDataFolder;
                    row.LocalDataPath = frm.LocalDataFolder;
                    row.DataType = frm.RemoteDataType;
                    dmisMenuItems.MenuItems.AddMenuItemsRow(row);
                    dmisMenuItems.AcceptChanges();
                    UpDateProgramList();
                    SaveData();
                }
                else
                {
                    return; // New program not added.
                }

            }
           
        }

        private void MenuItem_EditProgram_Click(object sender, EventArgs e)
        {
            DmisMenuItems.MenuItemsRow row = SelectedRow();
            if (row == null) return;

            String[] probeList = CMMsession.ProbeList();
            using (AddProgramForm frm = new AddProgramForm(DefaultPcdmisPath, probeList))
            {
                frm.btnOk.Text = "Save Changes";
                frm.ProgramName = row.ItemName;
                frm.ApplicationFolder = row.AppName;
                frm.PcdmisProgram = row.ProgamName;
                frm.DefaultProbe = row.DefaultTip;
                frm.HasRemoteDataCopy = row.UsesDataCopy;
                if (row.UsesDataCopy)
                {
                    frm.RemoteDataFolder = row.RemoteDataPath;
                    frm.LocalDataFolder = row.LocalDataPath;
                    frm.RemoteDataType = row.DataType;
                }

                DialogResult result = frm.ShowDialog();
                if (result == DialogResult.OK)
                {
                    row.ItemName = frm.ProgramName;
                    row.AppName = frm.ApplicationFolder;
                    row.ProgamName = frm.PcdmisProgram;
                    row.DefaultTip = frm.DefaultProbe;
                    row.UsesDataCopy = frm.HasRemoteDataCopy;
                    row.RemoteDataPath = frm.RemoteDataFolder;
                    row.LocalDataPath = frm.LocalDataFolder;
                    row.DataType = frm.RemoteDataType;
                    dmisMenuItems.AcceptChanges();
                    UpDateProgramList();
                    SaveData();
                }
            }
        }

        private void MenuItem_DeleteProgram_Click(object sender, EventArgs e)
        {
            DmisMenuItems.MenuItemsRow row = SelectedRow();
            if (row == null) return;

            dmisMenuItems.MenuItems.Rows.Remove(row);
            SaveData();
            DataView.ClearSelection();
            btnDataCopy.Enabled = false;
        }

        private void btnExecuteProgram_Click(object sender, EventArgs e)
        {
            DmisMenuItems.MenuItemsRow row = SelectedRow();
            if (row == null) return;

            CMMsession.ApplicationFolderName = row.AppName;
            String defaultTip = row.DefaultTip;
            if (!String.IsNullOrEmpty(defaultTip))
            {
                CMMsession.DefaultProbeName = defaultTip;
                String TipFileName = CMMsession.DefaultPcdmisPath + @"\pcd_Subroutines\TIP";
                using (StreamWriter writer = File.CreateText(TipFileName))
                {
                    writer.WriteLine(defaultTip);
                }
            }
            MeasurePart(row.ProgamName);
        }

        private void MenuItem_ApplicationSettings_Click(object sender, EventArgs e)
        {
            String InputPassword;

            using (PasswordForm frm = new PasswordForm())
            {
                DialogResult result1 = frm.ShowDialog();
                if (result1 == DialogResult.Cancel) return;
                InputPassword = frm.Password;
            }

            if (InputPassword == DmisMenu.Properties.Settings.Default.Password)
            {
                using (SettingsForm frm = new SettingsForm(DefaultPcdmisPath))
                {
                    DialogResult result2 = frm.ShowDialog();
                    if (result2 == DialogResult.Cancel) return;

                }
            }
            else
            {
                MessageBox.Show("Incorrect password", "Invalid Password", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
            }

            MessageBox.Show("After changing any settings you must quit and restart application.", "Warning", MessageBoxButtons.OK, MessageBoxIcon.Warning);

        }

        private void btnDataCopy_Click(object sender, EventArgs e)
        {
            DmisMenuItems.MenuItemsRow row = SelectedRow();
            if (row == null) return;

            if (!row.UsesDataCopy) return;

            using (DataCopyForm frm = new DataCopyForm(row.DataType, row.RemoteDataPath, row.LocalDataPath))
            {
                DialogResult result2 = frm.ShowDialog();
            }

        }

        private void DataView_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            DmisMenuItems.MenuItemsRow row = SelectedRow();
            if (row == null) return;

            if (row.UsesDataCopy)
            {
                btnDataCopy.Enabled = true;
                return;
            }
            else
            {
                btnDataCopy.Enabled = false;
            }
        }

        private void btnPcdmisWindow_Click(object sender, EventArgs e)
        {
            if (CMMsession.Visable == true)
            {
                CMMsession.Visable = false;
                return;
            }

            CMMsession.Visable = true;
        }

        // Event handler for mouse click on Main form window X box.
        private void MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            disconnectPCDMIS();
        }

        // Event handler for clicking on the 'Exit' menu item.
        private void Exit_MenuItem_Click(object sender, EventArgs e)
        {
            disconnectPCDMIS();
            this.Close();
        }

        // Event handler for clicking on 'Help->Work Instructions' menu item.
        private void MenuItem_ViewWI_Click(object sender, EventArgs e)
        {
            String wi = HomeDir + @"\" + Settings.Default.AppWI;
            if (!File.Exists(wi)) return;
            ShowPdfReport(wi);
        }

        /* ============================ DOTNET Event Handlers above this line =======================================*/
    }
}
