﻿using System;
using System.ComponentModel;
using System.IO;
using System.Windows.Forms;

namespace DmisMenu
{
    using Settings = DmisMenu.Properties.Settings;

    public partial class SettingsForm : Form
    {
        private String DefaultPcdmisPath;

        public SettingsForm(String PcdmisPath)
        {
            InitializeComponent();
            this.AcceptButton = btnOk;
            this.CancelButton = btnCancel;
            DefaultPcdmisPath = PcdmisPath;
            
            // Init text fields with current settings
            txbMainFormTitle.Text = Settings.Default.MainFormTitle;
            txbVersion.Text = Settings.Default.Version;
            txbPcdmisVersion.Text = Settings.Default.PcdmisVersion;
            txbCMMname.Text = Settings.Default.CMMname;
            txbAppWI.Text = Settings.Default.AppWI;
            txbAcrobatApp.Text = Settings.Default.AcrobatApp;
            txbPassword.Text = Settings.Default.Password;
            txbCMMname.Text = Settings.Default.CMMname;
        }

        private void btnFolder_Click(object sender, EventArgs e)
        {
            DialogResult result = FolderDialog.ShowDialog();
            if (result != DialogResult.OK) return; // Folder was not selected.

            String SelectedFolderPath = FolderDialog.SelectedPath;
            String senderName = ((Button)sender).Name;

            switch (senderName)
            {
                default:
                    break;
            }
        }

        private void btnFile_Click(object sender, EventArgs e)
        {
            FileDialog.Title = "Select file";
            FileDialog.RestoreDirectory = true;
            FileDialog.InitialDirectory = DefaultPcdmisPath;

            DialogResult result = FileDialog.ShowDialog();
            if (result != DialogResult.OK) return; // file was not selected.

            String senderName = ((Button)sender).Name;

            switch (senderName)
            {
                case "btnAppWI":
                    Settings.Default.AppWI = stripExtension(FileDialog.SafeFileName);
                    txbAppWI.Text = Settings.Default.AppWI;
                    break;
                case "btnAcrobatProg":
                    Settings.Default.AcrobatApp = FileDialog.FileName;
                    txbAcrobatApp.Text = Settings.Default.AcrobatApp;
                    break;
                default:
                    break;
            }
        }

        private void Validating_Click(object sender, CancelEventArgs e)
        {
            String senderName = ((TextBox)sender).Name;

            switch (senderName)
            {
                case "txbPassword":
                    Settings.Default.Password = txbPassword.Text;
                    txbPassword.Text = Settings.Default.Password;
                    break;
                case "txbMainFormTitle":
                    Settings.Default.MainFormTitle = txbMainFormTitle.Text;
                    txbMainFormTitle.Text = Settings.Default.MainFormTitle;
                    break;
                case "txbVersion":
                    Settings.Default.Version = txbVersion.Text;
                    txbVersion.Text = Settings.Default.Version;
                    break;
                case "txbPcdmisVersion":
                    Settings.Default.PcdmisVersion = txbPcdmisVersion.Text;
                    txbVersion.Text = Settings.Default.PcdmisVersion;
                    break;
                case "txbCMMname":
                    Settings.Default.CMMname = txbCMMname.Text;
                    txbCMMname.Text = Settings.Default.CMMname;
                    break;
                default:
                    break;
            }
        }

        protected string stripExtension(String fileName)
        {
            return Path.GetFileNameWithoutExtension(fileName);
        }

        private void btnOk_Click(object sender, EventArgs e)
        {
            Properties.Settings.Default.Save();
            this.DialogResult = System.Windows.Forms.DialogResult.OK;
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
        }
    }
}
